Method: Object#sql_expr
- Defined in:
- lib/sequel/extensions/sql_expr.rb
#sql_expr ⇒ Object
Return a copy of the object wrapped in a Sequel::SQL::GenericComplexExpression. Allows easy use of the Object with Sequel’s DSL. You’ll probably have to make sure that Sequel knows how to literalize the object properly, though.
41 42 43 |
# File 'lib/sequel/extensions/sql_expr.rb', line 41 def sql_expr Sequel::SQL::GenericComplexExpression.new(:NOOP, self) end |